## What

Describe what this PR changes.

## Why

Explain the motivation / bug / feature.

## How

Implementation notes and tradeoffs.

## Checklist

- [ ] Tests added/updated
- [ ] `ruff check .` and `ruff format .` pass
- [ ] `mypy src/pyaileys` passes
- [ ] README/docs updated if needed
- [ ] No secrets/auth state committed

